Riska novērtējuma veikšana ar OiRA | OiRA

Temati

# Riska novērtējuma veikšana ar OiRA

## Jaunas sesijas sākšana

Lai sāktu jaunu riska novērtējumu, noklikšķiniet uz saites “Sākt jaunu sesiju”.

## Riska novērtējuma atvēršana

Kad esat sācis riska novērtējumu, jūs jebkurā laikā varat izgūt to no infopaneļa sadaļā “Mani riska novērtējumi”. Šeit jūs varat arī sākt jaunu riska novērtējumu.

Infopanelis.

## Navigācija riska novērtējumā

Katram riska novērtējumam ir vairāki posmi. Tie ir redzami galvenajā izvēlnē ekrāna kreisajā pusē:

- Sagatavošanās
- Iesaiste
- Identifikācija + izvērtējums
- Rīcības plāns
- Ziņojums
- Statuss

Katra rīka struktūra var atšķirties atkarībā no OiRA partneru/rīku izstrādātāju pieņemtajiem lēmumiem. Dažos rīkos riska identifikācijas un izvērtējuma posms ietver rīcības plānu. Šajā gadījumā izvēlne kreisajā pusē ir šāda:

- Sagatavošanās
- Iesaiste
- Novērtējums
- Ziņojums
- Statuss

## Sagatavošanās

Ar “Sagatavošanos” jūs sākat katru sesiju/rīku. Šeit jūs riska novērtējumam piešķirat nosaukumu, kas jums vēlāk palīdzēs atšķirt vairākus dažādus riska novērtējumus, kurus esat veicis ar šo rīku.

Saite “Uzzināt vairāk par šo rīku” sniedz papildu informāciju par izvēlēto rīku un tā izstrādē iesaistītajām personām.

Noklikšķinot uz “Sākt”, atkarībā no izmantotā rīka var tikt uzdoti daži papildu jautājumi. Šis sagatavošanas ekrāns ar “profila jautājumiem” parādās tikai tajos rīkos, kas piedāvā šo iespēju.

Šeit jūs varat:

- atlasīt vai izlaist situāciju(-as) atkarībā no tā, vai tā(-s) attiecas uz jūsu uzņēmējdarbību. Attiecīgā gadījumā izvēlieties “jā”;
- uzskaitīt vairākas uzņēmējdarbības vienības, filiāles vai veikalus utt. Saistītie riski tiks atkārtoti katram ierakstam.

Ekrāns “Profils” sagatavošanās posmā

Sagatavošanās posms ir ļoti svarīgs, jo tajā precīzi tiek definēts uzņēmējdarbības veids un saistītie riski, ar kādiem jūsu uzņēmums saskaras. Noklikšķinot uz “Saglabāt un turpināt”, jūs pāriesiet uz nākamo sadaļu “Iesaiste”.

Piezīme. Daudziem rīkiem nav profila jautājumu, jo tie neizmanto šo funkciju. Šādā gadījumā šis ekrāns tiek automātiski izlaists.

## Iesaiste

Šis posms ir atgādinājums par to, cik svarīga ir darba ņēmēju iesaiste, un tajā piedāvā dažādus veidus, kā nodrošināt darba ņēmēju labu iesaisti. Šeit jūs varat lejupielādēt vai izdrukāt riska novērtējuma saturu, lai to kopīgotu ar saviem darba ņēmējiem/darbiniekiem. Tādējādi tiek nodrošināts, ka darba ņēmēji var sniegt ieguldījumu situācijas novērtēšanā darba vietā.

## Novērtējums

Šajā posmā jūs identificēsiet apdraudējumus un problēmas, kas attiecas uz jūsu uzņēmumu.

Piezīme. Atkarībā no tā, kā OiRA partneris ir konfigurējis rīku, šajā ekrānā var būt integrēts posms “Rīcības plāns” (sk. turpmāk). Šajā gadījumā visu posmu sauc par “Novērtējumu” un sadaļā “Rīcības plāns” aprakstītie elementi parādīsies pie katra riska identifikācijas un izvērtējuma.

Identifikācija un izvērtējums.

Ekrāna kreisajā pusē zem “Identifikācija + izvērtējums”/“Novērtējums” jūs varat redzēt katru no rīkā iekļautajiem tematiem/moduļiem. Temats, ko pašlaik aplūkojat, ir izcelts.

### Identifikācija

Attiecībā uz katru risku jums ir jāizlemj, vai apgalvojums, kurā aprakstīts vēlamais stāvoklis, attiecas uz jūsu uzņēmumu. Jūs varat atbildēt šādi:

- Jā: ja uz apgalvojumu atbildat ar “jā”, turpmāka rīcība nav nepieciešama, jo esat novērtējis risku kā neesošu.
- Nē: ja uz apgalvojumu atbildat ar “nē”, ir vajadzīga turpmāka rīcība. Jums prasīs izlemt par konkrētiem pasākumiem.
- Nepiemēro: dažos riska apgalvojumos ir dota iespēja izvēlēties “nepiemēro”, ja risks neattiecas uz jūsu uzņēmumu/iestādi.

Zem katra apgalvojuma parasti ir vairāk informācijas par konkrēto risku.

- Informācija: īss apraksts, dažkārt kopā ar attēliem, sniedzot sīkāku informāciju par risku.
- Resursi: papildu informācija par risku, piemēram, atsauces uz tiesību aktiem un politiku. Dažkārt šeit var atrast arī pievienotus dokumentus plašākai uzziņai.
- Komentāri: šeit jūs varat ierakstīt savus komentārus, kas parādīsies jūsu ziņojumā novērtējuma beigās.

Atbildot uz apgalvojumu par risku un ejot tālāk, izvēlne kreisajā pusē tiks atjaunināta ar krāsainu simbolu, lai norādītu, vai jūs:

- atbildējāt apstiprinoši (zaļš ķeksītis);
- atbildējāt noraidoši (sarkans krustiņš);
- atlikāt atbildes sniegšanu (oranža jautājuma zīme).

Attiecībā uz neatbildētiem jautājumiem saglabājas pelēkais simbols.

### Izvērtējums

Šajā posmā jūs izvērtējat identificētā riska prioritāti.

Riska izvērtēšana.

Piezīme. Dažos OiRA rīkos izvērtējums nav parādīts. Tas ir atkarīgs no tā, kā valsts partneris / OiRA rīka izstrādātājs ir izveidojis konkrēto OiRA rīku.

Ja identificējāt risku kā pastāvošu (atzīmēts ar sarkanu krustiņu), parādīsies izvērtēšanas sadaļa. Atkarībā no katram riskam iestatītās izvērtēšanas metodes jums tiks prasīts:

- novērtēt prioritāti — augsta, vidēja vai zema;

Riska prioritātes noteikšana.

VAI

- atbildēt uz dažiem jautājumiem par riska biežumu, nopietnību un varbūtību, lai varētu aprēķināt prioritāti, pamatojoties uz jūsu atbildēm.

Mainīgo lielumu noteikšana riskam.

### Nozares noteiktie prioritārie riski:

Dažus riskus par ļoti svarīgiem uzskata valsts partneris / rīka izstrādātājs, kurš izveidojis konkrēto OiRA rīku. Jums nav jānovērtē šādi “prioritāri riski”, jo to prioritāte automātiski tiks noteikta kā “augsta”.

Prioritārie riski.

### Specifiski riski

Pēc tam, kad atbildēti visi riska temati sadaļā “Identifikācija un izvērtējums”/“Novērtējums”, jūs nonāksiet pie fakultatīvā temata “Citi riski”. Šeit poga “Pievienot specifisku risku” ļauj jums izveidot savus ierakstus.

Ja rīkā nav norādīti riski, kas pastāv jūsu darba vietā/uzņēmumā, jums tie ir jāpievieno šeit. Jūs varat pilnībā definēt/frāzēt šos riskus.

Specifiski riski.

“Specifisks risks” ir ļoti līdzīgs OiRA rīka radītajiem riskiem, taču ir skaidrs, ka jums ir jāieraksta savs teksts. Šim tekstam ir jābūt vismaz īsam apgalvojumam, kurā apraksta problemātisku situāciju, paredzot iespēju sniegt garāku aprakstu. Jūs varat arī augšupielādēt attēlu, lai ilustrētu konkrētu situāciju.

Tāpat kā attiecībā uz parastajiem riskiem, jums ir jānorāda, vai risks pastāv. Tas jums ļaus atlasīt specifiskos riskus pēc tam, kad būsiet tos sekmīgi novērsis, bet tie tiks saglabāti jūsu riska novērtējumā dokumentēšanas nolūkā.

Jūs varat pievienot tik lielu skaitu specifisku risku, cik vajadzīgs.

Pievienot specifisku risku.

## Rīcības plāns

Šajā posmā jūs izlemjat, kādus pasākumus vēlaties īstenot, lai novērstu vai mazinātu iepriekš identificētos riskus.

Piezīme: Kā minēts iepriekš, rīcības plāns ir parādīts kā atsevišķs posms izvēlnē kreisajā pusē vai parādās zem katra identificētā riska. Pēdējā minētajā gadījumā šis posms izvēlnē ir dēvēts par “novērtējumu” un ietver gan riska apgalvojumus, gan atbilžu izvēli.

Tas, kāda versija jums ir nodrošināta, ir atkarīgs no valsts OiRA partnera / rīka izstrādātāja pieņemtajiem lēmumiem.

### Integrēts rīcības plāns

Integrēts rīcības plāns.

Ja jūs atbildat uz jautājumu ar “nē”, rīcības plāna modulis atvērsies lapā zem virsraksta “Pasākumi”.

Jūs varat izvēlēties pasākumus no sistēmas piedāvāto pasākumu saraksta vai definēt savus pasākumus.

### Atsevišķs rīcības plāns

Ja rīcības plāns ir atsevišķs posms, tas būs pieejams, izmantojot navigāciju pa kreisi.

Noklikšķiniet uz pogas “Izveidot rīcības plānu”, lai sāktu savu plānu.

Rīcības plāna posmā izvēlne kreisajā pusē parāda tikai tos riskus, kas iezīmēti turpmākai rīcībai, jo pārējie riski tika atzīmēti kā neesoši.

Attiecībā uz katru risku, par kuru novērtēšanas procesā atbildēts ar “nē”, un prioritārajiem riskiem (neatkarīgi no tā, vai atbilde ir apstiprinoša vai noraidoša) jums prasīs definēt pasākumus.

Risks rīcības plānā.

Jūs varat vai nu izvēlēties pasākumus no sistēmas ieteikto pasākumu saraksta, vai arī definēt savus pasākumus.

#### Pievienot savu pasākumu

Papildu pasākuma pievienošana.

Lai sāktu definēt preventīvu pasākumu, izmantojiet pogu “Pievienot pasākumu”. Jums ir:

- jāapraksta vispārējā pieeja, kas tiks izmantota, lai novērstu vai mazinātu risku,
- fakultatīvi jānorāda vajadzīgais kompetences un/vai prasību līmenis (piemēram, šeit varat piebilst, vai ir vajadzīga īpaša apmācība vai ārēja kompetence, lai novērstu šo risku),
- jāieraksta informācija par to, kurš atbild par īstenošanu,
- attiecīgā gadījumā jānosaka budžets,
- fakultatīvi jānorāda datumi, kad sākt īstenot pasākumu un kad plānojat to pabeigt.

Jūs varat pievienot tik daudz pasākumu, cik nepieciešams.

#### Pievienot standarta pasākumus

Atkarībā no tā, kā OiRA partneris / rīka izstrādātājs ir izveidojis rīku, individuāliem riskiem ir pieejami iepriekš definēti pasākumi. Lai izvēlētos vienu vai vairākus iepriekš definētus pasākumus, noklikšķiniet uz pogas “Atlasīt standarta pasākumus”.

Atveras uznirstošā izvēlne, kurā redzami visi ieteiktie pasākumi. Noklikšķiniet uz pogas “Pievienot”, lai atzīmētu pasākumus, ko vēlaties izmantot.

Iepriekš definētie pasākumi tad tiek uzskaitīti jūsu rīcības plānā. Apraksts par to, kas jādara, ir noteikts, bet pārējos laukus (atbildību, budžetu, datumus) varat aizpildīt jūs.

Standarta pasākumu pievienošana.

Gan standarta pasākumus, gan jūsu definētos pasākumus jūs varat atkal dzēst jebkurā brīdī.

## Ziņojums

Pēc rīcības plāna pabeigšanas jūs varat sagatavot ziņojumu.

Ja vēlaties atstāt komentāru, kas jāiekļauj ziņojumā, ierakstiet šeit savu tekstu un saglabājiet to.

Komentēt ziņojumu.

Skatīt šeit, lai uzzinātu vairāk par dažādiem ziņojumiem un kā tos izmantot.

## Statuss

Mazajā sektoru diagrammā izvēlnē kreisajā pusē ir parādīts progress, kas panākts ar šo rīku.

Statusa sadaļā ir sniegts pārskats par to, cik daudz risku esat identificējis, cik daudzi no tiem ir novērsti, pieņemot lēmumu par pasākumiem, un uz cik riskiem/apgalvojumiem jūs joprojām neesat reaģējuši.

Statusa lapa.

Ienākot statusa ekrānā, jūs varat redzēt, cik tālu esat pavirzījies uz priekšu katrā modulī. Tas jums var palīdzēt noteikt, kur vēl ir jānovērtē riski vai jāveic pasākumi attiecībā uz identificētajiem riskiem.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More